@@ -3,7 +3,8 @@ use warnings;
 
 package IO::CaptureOutput;
 # ABSTRACT: capture STDOUT and STDERR from Perl code, subprocesses or XS
-our $VERSION = '1.1103'; # VERSION
+
+our $VERSION = '1.1104';
 
 use vars qw/@ISA @EXPORT_OK %EXPORT_TAGS $CarpLevel/;
 use Exporter;
@@ -23,7 +24,7 @@ sub _capture (&@) { ## no critic
       croak $error if $error;
     }
 
-    # if either $output or $error are defined, then we need a variable for 
+    # if either $output or $error are defined, then we need a variable for
     # results; otherwise we only capture to files and don't waste memory
     if ( defined $output || defined $error ) {
       for ($output, $error) {
@@ -32,25 +33,25 @@ sub _capture (&@) { ## no critic
       }
     }
 
-    # merge if same refs for $output and $error or if both are undef -- 
+    # merge if same refs for $output and $error or if both are undef --
     # i.e. capture \&foo, undef, undef, $merged_file
     # this means capturing into separate files *requires* at least one
     # capture variable
-    my $should_merge = 
-      (defined $error && defined $output && $output == $error) || 
-      ( !defined $output && !defined $error ) || 
+    my $should_merge =
+      (defined $error && defined $output && $output == $error) ||
+      ( !defined $output && !defined $error ) ||
       0;
 
     my ($capture_out, $capture_err);
 
-    # undef means capture anonymously; anything other than \undef means 
+    # undef means capture anonymously; anything other than \undef means
     # capture to that ref; \undef means skip capture
-    if ( !defined $output || $output != \undef ) { 
+    if ( !defined $output || $output != \undef ) {
         $capture_out = IO::CaptureOutput::_proxy->new(
             'STDOUT', $output, undef, $output_file
         );
     }
-    if ( !defined $error || $error != \undef ) { 
+    if ( !defined $error || $error != \undef ) {
         $capture_err = IO::CaptureOutput::_proxy->new(
             'STDERR', $error, ($should_merge ? 'STDOUT' : undef), $error_file
         );
@@ -64,7 +65,7 @@ sub _capture (&@) { ## no critic
 # Extra indirection for symmetry with capture_exec, etc.  Gets error reporting
 # to the right level
 sub capture (&@) { ## no critic
-    return &_capture; 
+    return &_capture;
 }
 
 sub capture_exec {
@@ -112,7 +113,7 @@ sub _validate {
     my $msg = q{};
 
     # \$out, \$out, $outfile, $errfile
-    if (    defined $output && defined $error  
+    if (    defined $output && defined $error
         &&  defined $output_file && defined $error_file
         &&  $output == $error
         &&  $output != \undef
@@ -121,7 +122,7 @@ sub _validate {
       $msg = "Merged STDOUT and STDERR, but specified different output and error files";
     }
     # undef, undef, $outfile, $errfile
-    elsif ( !defined $output && !defined $error  
+    elsif ( !defined $output && !defined $error
         &&  defined $output_file && defined $error_file
         &&  $output_file ne $error_file
     ) {
@@ -184,7 +185,7 @@ sub new {
 sub DESTROY {
     my $self = shift;
 
-    my ($pid, $orig_fh, $saved_fh, $capture_var, $newio_fh, 
+    my ($pid, $orig_fh, $saved_fh, $capture_var, $newio_fh,
       $newio_file, $capture_file) = @$self;
     return unless $pid eq $$; # only cleanup in the process that is capturing
 
@@ -204,7 +205,7 @@ sub DESTROY {
         # some versions of perl complain about reading from fd 1 or 2
         # which could happen if STDOUT and STDERR were closed when $newio
         # was opened, so we just squelch warnings here and continue
-        local $^W; 
+        local $^W;
         seek $newio_fh, 0, 0;
         $$capture_var = do {local $/; <$newio_fh>};
     }
@@ -230,179 +231,179 @@ IO::CaptureOutput - capture STDOUT and STDERR from Perl code, subprocesses or XS
 
 =head1 VERSION
 
-version 1.1103
+version 1.1104
 
 =head1 SYNOPSIS
 
-     use IO::CaptureOutput qw(capture qxx qxy);
- 
-     # STDOUT and STDERR separately
-     capture { noisy_sub(@args) } \$stdout, \$stderr;
- 
-     # STDOUT and STDERR together
-     capture { noisy_sub(@args) } \$combined, \$combined;
- 
-     # STDOUT and STDERR from external command
-     ($stdout, $stderr, $success) = qxx( @cmd );
- 
-     # STDOUT and STDERR together from external command
-     ($combined, $success) = qxy( @cmd );
+    use IO::CaptureOutput qw(capture qxx qxy);
+
+    # STDOUT and STDERR separately
+    capture { noisy_sub(@args) } \$stdout, \$stderr;
+
+    # STDOUT and STDERR together
+    capture { noisy_sub(@args) } \$combined, \$combined;
+
+    # STDOUT and STDERR from external command
+    ($stdout, $stderr, $success) = qxx( @cmd );
+
+    # STDOUT and STDERR together from external command
+    ($combined, $success) = qxy( @cmd );
 
 =head1 DESCRIPTION
 
 B<This module is no longer recommended by the maintainer> - see
 L<Capture::Tiny> instead.
 
-This module provides routines for capturing STDOUT and STDERR from perl 
-subroutines, forked system calls (e.g. C<<< system() >>>, C<<< fork() >>>) and from 
-XS or C modules.
+This module provides routines for capturing STDOUT and STDERR from perl
+subroutines, forked system calls (e.g. C<system()>, C<fork()>) and from XS
+or C modules.
 
 =head1 NAME
 
-=head1 VERSION
-
-This documentation describes version %%VERSION%%.
-
 =head1 FUNCTIONS
 
 The following functions will be exported on demand.
 
 =head2 capture()
 
-     capture \&subroutine, \$stdout, \$stderr;
+    capture \&subroutine, \$stdout, \$stderr;
 
-Captures everything printed to C<<< STDOUT >>> and C<<< STDERR >>> for the duration of
-C<<< &subroutine >>>. C<<< $stdout >>> and C<<< $stderr >>> are optional scalars that will contain
-C<<< STDOUT >>> and C<<< STDERR >>> respectively. 
+Captures everything printed to C<STDOUT> and C<STDERR> for the duration of
+C<&subroutine>. C<$stdout> and C<$stderr> are optional scalars that will
+contain C<STDOUT> and C<STDERR> respectively.
 
-C<<< capture() >>> uses a code prototype so the first argument can be specified directly within 
-brackets if desired.
+C<capture()> uses a code prototype so the first argument can be specified
+directly within brackets if desired.
 
-     # shorthand with prototype
-     capture { print __PACKAGE__ } \$stdout, \$stderr;
+    # shorthand with prototype
+    capture C< print __PACKAGE__ > \$stdout, \$stderr;
 
-Returns the return value(s) of C<<< &subroutine >>>. The sub is called in the same
-context as C<<< capture() >>> was called e.g.:
+Returns the return value(s) of C<&subroutine>. The sub is called in the
+same context as C<capture()> was called e.g.:
 
-     @rv = capture { wantarray } ; # returns true
-     $rv = capture { wantarray } ; # returns defined, but not true
-     capture { wantarray };       # void, returns undef
+    @rv = capture C< wantarray > ; # returns true
+    $rv = capture C< wantarray > ; # returns defined, but not true
+    capture C< wantarray >;       # void, returns undef
 
-C<<< capture() >>> is able to capture output from subprocesses and C code, which
-traditional C<<< tie() >>> methods of output capture are unable to do.
+C<capture()> is able to capture output from subprocesses and C code, which
+traditional C<tie()> methods of output capture are unable to do.
 
-B<Note:> C<<< capture() >>> will only capture output that has been written or flushed
-to the filehandle.
+B<Note:> C<capture()> will only capture output that has been written or
+flushed to the filehandle.
 
-If the two scalar references refer to the same scalar, then C<<< STDERR >>> will be
-merged to C<<< STDOUT >>> before capturing and the scalar will hold the combined
-output of both.
+If the two scalar references refer to the same scalar, then C<STDERR> will
+be merged to C<STDOUT> before capturing and the scalar will hold the
+combined output of both.
 
-     capture \&subroutine, \$combined, \$combined;
+    capture \&subroutine, \$combined, \$combined;
 
-Normally, C<<< capture() >>> uses anonymous, temporary files for capturing output.
-If desired, specific file names may be provided instead as additional options.
+Normally, C<capture()> uses anonymous, temporary files for capturing
+output.  If desired, specific file names may be provided instead as
+additional options.
 
-     capture \&subroutine, \$stdout, \$stderr, $out_file, $err_file;
+    capture \&subroutine, \$stdout, \$stderr, $out_file, $err_file;
 
-Files provided will be clobbered, overwriting any previous data, but
-will persist after the call to C<<< capture() >>> for inspection or other manipulation.
+Files provided will be clobbered, overwriting any previous data, but will
+persist after the call to C<capture()> for inspection or other
+manipulation.
 
-By default, when no references are provided to hold STDOUT or STDERR, output
-is captured and silently discarded.
+By default, when no references are provided to hold STDOUT or STDERR,
+output is captured and silently discarded.
 
-     # Capture STDOUT, discard STDERR
-     capture \&subroutine, \$stdout;
- 
-     # Discard STDOUT, capture STDERR
-     capture \&subroutine, undef, \$stderr;
+    # Capture STDOUT, discard STDERR
+    capture \&subroutine, \$stdout;
 
-However, even when using C<<< undef >>>, output can be captured to specific files.
+    # Discard STDOUT, capture STDERR
+    capture \&subroutine, undef, \$stderr;
 
-     # Capture STDOUT to a specific file, discard STDERR
-     capture \&subroutine, \$stdout, undef, $outfile;
- 
-     # Discard STDOUT, capture STDERR to a specific file
-     capture \&subroutine, undef, \$stderr, undef, $err_file;
- 
-     # Discard both, capture merged output to a specific file
-     capture \&subroutine, undef, undef, $mergedfile;
+However, even when using C<undef>, output can be captured to specific
+files.
 
-It is a fatal error to merge STDOUT and STDERR and request separate, specific
-files for capture.
+    # Capture STDOUT to a specific file, discard STDERR
+    capture \&subroutine, \$stdout, undef, $outfile;
 
-     # ERROR:
-     capture \&subroutine, \$stdout, \$stdout, $out_file, $err_file;
-     capture \&subroutine, undef, undef, $out_file, $err_file;
+    # Discard STDOUT, capture STDERR to a specific file
+    capture \&subroutine, undef, \$stderr, undef, $err_file;
 
-If either STDOUT or STDERR should be passed through to the terminal instead of
-captured, provide a reference to undef -- C<<< \undef >>> -- instead of a capture
-variable.
+    # Discard both, capture merged output to a specific file
+    capture \&subroutine, undef, undef, $mergedfile;
 
-     # Capture STDOUT, display STDERR
-     capture \&subroutine, \$stdout, \undef;
- 
-     # Display STDOUT, capture STDERR
-     capture \&subroutine, \undef, \$stderr;
+It is a fatal error to merge STDOUT and STDERR and request separate,
+specific files for capture.
+
+    # ERROR:
+    capture \&subroutine, \$stdout, \$stdout, $out_file, $err_file;
+    capture \&subroutine, undef, undef, $out_file, $err_file;
+
+If either STDOUT or STDERR should be passed through to the terminal instead
+of captured, provide a reference to undef -- C<\undef> -- instead of a
+capture variable.
+
+    # Capture STDOUT, display STDERR
+    capture \&subroutine, \$stdout, \undef;
+
+    # Display STDOUT, capture STDERR
+    capture \&subroutine, \undef, \$stderr;
 
 =head2 capture_exec()
 
-     ($stdout, $stderr, $success, $exit_code) = capture_exec(@args);
+    ($stdout, $stderr, $success, $exit_code) = capture_exec(@args);
 
-Captures and returns the output from C<<< system(@args) >>>. In scalar context,
-C<<< capture_exec() >>> will return what was printed to C<<< STDOUT >>>. In list context,
-it returns what was printed to C<<< STDOUT >>> and C<<< STDERR >>> as well as a success
-flag and the exit value.
+Captures and returns the output from C<system(@args)>. In scalar context,
+C<capture_exec()> will return what was printed to C<STDOUT>. In list
+context, it returns what was printed to C<STDOUT> and C<STDERR> as well as
+a success flag and the exit value.
 
-     $stdout = capture_exec('perl', '-e', 'print "hello world"');
- 
-     ($stdout, $stderr, $success, $exit_code) = 
-         capture_exec('perl', '-e', 'warn "Test"');
+    $stdout = capture_exec('perl', '-e', 'print "hello world"');
 
-C<<< capture_exec >>> passes its arguments to C<<< system() >>> and on MSWin32 will protect
-arguments with shell quotes if necessary.  This makes it a handy and slightly
-more portable alternative to backticks, piped C<<< open() >>> and C<<< IPC::Open3 >>>.
+    ($stdout, $stderr, $success, $exit_code) =
+        capture_exec('perl', '-e', 'warn "Test"');
 
-The C<<< $success >>> flag returned will be true if the command ran successfully and
-false if it did not (if the command could not be run or if it ran and
+C<capture_exec> passes its arguments to C<system()> and on MSWin32 will
+protect arguments with shell quotes if necessary.  This makes it a handy
+and slightly more portable alternative to backticks, piped C<open()> and
+C<IPC::Open3>.
+
+The C<$success> flag returned will be true if the command ran successfully
+and false if it did not (if the command could not be run or if it ran and
 returned a non-zero exit value).  On failure, the raw exit value of the
-C<<< system() >>> call is available both in the C<<< $exit_code >>> returned and in the C<<< $? >>>
-variable.
+C<system()> call is available both in the C<$exit_code> returned and in the
+C<$?> variable.
 
-   ($stdout, $stderr, $success, $exit_code) = 
-       capture_exec('perl', '-e', 'warn "Test" and exit 1');
- 
-   if ( ! $success ) {
-       print "The exit code was " . ($exit_code >> 8) . "\n";
-   }
+  ($stdout, $stderr, $success, $exit_code) =
+      capture_exec('perl', '-e', 'warn "Test" and exit 1');
 
-See L<perlvar> for more information on interpreting a child process
-exit code.
+  if ( ! $success ) {
+      print "The exit code was " . ($exit_code >> 8) . "\n";
+  }
+
+See L<perlvar> for more information on interpreting a child process exit
+code.
 
 =head2 capture_exec_combined()
 
-     ($combined, $success, $exit_code) = capture_exec_combined(
-         'perl', '-e', 'print "hello\n"', 'warn "Test\n"
-     );
+    ($combined, $success, $exit_code) = capture_exec_combined(
+        'perl', '-e', 'print "hello\n"', 'warn "Test\n"
+    );
 
-This is just like C<<< capture_exec() >>>, except that it merges C<<< STDERR >>> with C<<< STDOUT >>>
-before capturing output.
+This is just like C<capture_exec()>, except that it merges C<STDERR> with
+C<STDOUT> before capturing output.
 
-B<Note:> there is no guarantee that text printed to C<<< STDOUT >>> and C<<< STDERR >>> in the
-subprocess will be appear in order. The actual order will depend on how IO
-buffering is handled in the subprocess.
+B<Note:> there is no guarantee that text printed to C<STDOUT> and C<STDERR>
+in the subprocess will be appear in order. The actual order will depend on
+how IO buffering is handled in the subprocess.
 
 =head2 qxx()
 
-This is an alias for C<<< capture_exec() >>>.
+This is an alias for C<capture_exec()>.
 
 =head2 qxy()
 
-This is an alias for C<<< capture_exec_combined() >>>.
+This is an alias for C<capture_exec_combined()>.
 
 =head1 SEE ALSO
 
-=over
+=over 4
 
 =item *
 
@@ -461,25 +462,27 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Mike Latimer Olivier Mengué Tony Cook
+
 =over 4
 
 =item *
 
+Mike Latimer <mlatimer@suse.com>
+
+=item *
+
 Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
 Tony Cook <tony@develop-help.com>
 
-=item *
-
-unknown <dgolden@.(none)>
-
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Simon Flack and David Golden.
+This software is copyright (c) 2015 by Simon Flack and David Golden.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
